Below follows an overview of the developed graphical interface to be used in the data treatment.


Viewer3D
^^^^^^^^

Quick visualization tool designed to deal with the difficulties of handling 3D data. Through simple keybord inputs one can look through the data along the principal axis.



.. automodule:: Viewer3D

.. _Viewer3D:

.. autoclass:: Viewer3D
    :members:

    .. automethod:: __init__

